Storage
=======

.. module:: plone.scale.storage
   :synopsis: Storage and retrieval of scaled images

In Zope environments there are many possible types of objects which
can have images, and just as many ways to store an image. In order to
handle all of these two types of adapters are used: an :class:`IImageData`
adapter which can retrieve the data from an image field and an
:class:`IImageScaleStorage` adapter which manages generation and retrieval
of scaled images of fields on an object.

Scales can be retrieved using either their scaling parameters or via an
identification code generated by the storage.


Interfaces
-----------

.. autointerface:: IImageScaleStorage
   :members:


Classes
--------

.. autoclass:: AnnotationStorage
   :members: scale

